@@ -8,8 +8,8 @@ created 31-mar-2019 by richb@instantlinux.net
 import alembic.config
 import alembic.script
 from alembic.runtime.environment import EnvironmentContext
-from datetime import datetime
-from flask import _app_ctx_stack, abort, g, request
+from flask import _app_ctx_stack, g
+from flask_babel import _
 import logging
 import os.path
 from sqlalchemy import create_engine
@@ -24,9 +24,7 @@ import time
 import yaml
 
 from .const import Constants
-from .metrics import Metrics
-from .ratelimit import RateLimit
-from .session_manager import Mutex, SessionManager
+from .session_manager import Mutex
 from .service_config import ServiceConfig
 
 Base = declarative_base()
@@ -67,23 +65,6 @@ def get_session(scopefunc=None, scoped=True, db_url=None, engine=None):
         return Session
 
 
-def before_request():
-    """flask session setup - database and metrics
-    """
-    g.db = get_session()
-    g.session = SessionManager()
-    g.request_start_time = datetime.utcnow()
-    try:
-        resource = request.url_rule.rule.split('/')[3]
-    except Exception:
-        resource = None
-    if resource != 'metrics':
-        Metrics().store('api_calls_total', labels=['resource=%s' % resource])
-    if request.method != 'OPTIONS' and RateLimit().call():
-        Metrics().store('api_errors_total', labels=['code=%d' % 429])
-        abort(429)
-
-
 def initialize_db(db_url=None, engine=None, redis_conn=None):
     """initialize database connectivity
 
@@ -95,7 +76,6 @@ def initialize_db(db_url=None, engine=None, redis_conn=None):
     Returns:
       bool: True if successful
     """
-
     config = ServiceConfig().config
     models = ServiceConfig().models
     _init_db(db_url=db_url, geo_support=config.DB_GEO_SUPPORT,
@@ -114,6 +94,22 @@ def initialize_db(db_url=None, engine=None, redis_conn=None):
     return True
 
 
+def db_abort(error, rollback=False, **kwargs):
+    """Helper for logging exceptions
+    Args:
+      error (str): exception string for log
+      rollback (bool): whether to roll back
+      kwargs: any other values to log
+
+    Returns:
+      tuple: dict with generic message, status 500
+    """
+    msg = _(u'DB operational error')
+    logging.error(dict(message=msg, error=error, **kwargs))
+    g.db.rollback()
+    return dict(message=msg), 500
+
+
 def alembic_migrate(models, version, script_location, migrate=False,
                     db_session=None, schema_maxtime=0, seed_func=None):
     """run schema migrations
@@ -225,6 +221,8 @@ def seed_new_db(db_session):
             records['tz'] = yaml.safe_load(f)['tz']
     models = ServiceConfig().models
     for resource, records in records.items():
+        if resource == '_constants':
+            continue
         for record in records:
             if 'geolat' in record:
                 # Store lat/long as fixed-precision integers
