@@ -5,17 +5,26 @@ created 28-mar-2020 by richb@instantlinux.net
 
 from flask import g
 
+from ._version import __version__
+
 
 def healthcheck(app_name='api', service_name='main', tests=None, model=None,
                 releaseId=None, build_date=None, version=None):
-    """Returns a health check report, with optional tests, in
-    format recommended by Nadareishvili in RFC draft
+    """Support for a standardized healthcheck endpoint - returns a
+    health check report, with optional tests, in format recommended by
+    Nadareishvili in RFC draft
     https://tools.ietf.org/id/draft-inadarei-api-health-check-04.html
 
-    params:
-      service_name - microservice name for serviceId
-      tests - optional tests to run
-      model - schema model (usually AlembicVersion)
+    Args:
+      app_name (str): the application name for description
+      service_name (str): microservice name for serviceId
+      tests (list): optional tests to run
+      model (obj): schema model (usually AlembicVersion)
+      releaseId (str): a release ID string
+      build_date (str): build timestamp
+      version (str): a version string
+    Returns:
+      tuple: first element is pass or fail, second is response code
     """
 
     status = 200
@@ -31,6 +40,8 @@ def healthcheck(app_name='api', service_name='main', tests=None, model=None,
         try:
             retval['notes'].append(
                 'schema:%s' % g.db.query(model).one().version_num)
+            retval['notes'].append(
+                'apicrud_version:%s' % __version__)
         except Exception as ex:
             retval['output'] = str(ex)
             status = 503
