@@ -7,16 +7,19 @@ from flask_babel import _
 import jwt
 import logging
 import os
+from sqlalchemy.exc import DataError, IntegrityError
+from sqlalchemy.orm.exc import NoResultFound
 
 from . import state
 from .access import AccessControl
 from .account_settings import AccountSettings
 from .const import Constants
 from .database import db_abort
+from .messaging.confirmation import Confirmation
 from .metrics import Metrics
 from .service_config import ServiceConfig
 from .service_registry import ServiceRegistry
-from .utils import gen_id, utcnow
+from .utils import gen_id, identity_normalize, utcnow
 
 OC = {}
 
@@ -67,8 +70,8 @@ class SessionAuth(object):
                                       redis_conn=self.redis_conn)
                 if ret[1] != 200:
                     return ret
-                return self._login_accepted(username, ret[3], method,
-                                            headers=ret[2])
+                return self.login_accepted(username, ret[3], method,
+                                           headers=ret[2])
             else:
                 logging.info(dict(error='otp token omitted', **logmsg))
                 return dict(message=_(u'access denied')), 403
@@ -76,7 +79,7 @@ class SessionAuth(object):
             ret = local_func.login(username, password)
             if ret[1] != 200:
                 return ret
-            return self._login_accepted(username, ret[2], 'local')
+            return self.login_accepted(username, ret[2], 'local')
         elif method in self.config.AUTH_PARAMS.keys():
             return oauth2_func.login(self.oauth, method, cache=Ocache())
         else:
@@ -84,7 +87,7 @@ class SessionAuth(object):
             logging.error(dict(message=msg, **logmsg))
             return dict(message=msg), 500
 
-    def _login_accepted(self, username, account, method, headers=None):
+    def login_accepted(self, username, account, method, headers=None):
         """Login accepted from provider: create a session
 
         Args:
@@ -98,7 +101,7 @@ class SessionAuth(object):
         try:
             g.db.commit()
         except Exception as ex:
-            return db_abort(str(ex), action='_login_accepted')
+            return db_abort(str(ex), action='login_accepted')
 
         # connexion doesn't support cookie auth. probably just as well,
         #  this forced me to implement a JWT design with nonce token
@@ -177,6 +180,92 @@ class SessionAuth(object):
                 return True
         return False
 
+    def register(self, identity, username, name, template='confirm_new',
+                 picture=None):
+        """Register a new account: create related records in database
+        and send confirmation token to new user
+
+        TODO caller still has to invoke account_add function to
+        generate record in accounts table
+
+        Args:
+          identity (str): account's primary identity, usually an email
+          username (str): account's username
+          name (str): name
+          picture (url): URL of an avatar / photo
+          template (str): template for message (confirming new user)
+        Returns:
+          tuple: the Confirmation.request dict and http response
+        """
+        if not username or not identity or not name:
+            return dict(message=_(u'all fields required')), 400
+        identity = identity_normalize(identity)
+        logmsg = dict(action='register', identity=identity,
+                      username=username)
+        try:
+            g.db.query(self.models.Account).filter_by(name=username).one()
+            msg = _(u'that username is already registered')
+            logging.warning(dict(message=msg, **logmsg))
+            return dict(message=msg), 405
+        except NoResultFound:
+            pass
+        uid = None
+        try:
+            existing = g.db.query(self.models.Person).filter_by(
+                identity=identity).one()
+            uid = existing.id
+            g.db.query(self.models.Account).filter_by(uid=uid).one()
+            msg = _(u'that email is already registered, use forgot-password')
+            logging.warning(dict(message=msg, **logmsg))
+            return dict(message=msg), 405
+        except NoResultFound:
+            pass
+        if uid:
+            try:
+                cid = g.db.query(self.models.Contact).filter_by(
+                    info=identity, type='email').one().id
+            except Exception as ex:
+                msg = 'registration trouble, error=%s' % str(ex)
+                logging.error(dict(message=msg, **logmsg))
+                return dict(message=msg), 405
+        else:
+            person = self.models.Person(
+                id=gen_id(prefix='u-'), name=name, identity=identity,
+                status='active')
+            uid = person.id
+            cid = gen_id()
+            g.db.add(person)
+            g.db.add(self.models.Contact(id=cid, uid=uid, type='email',
+                                         info=identity))
+            g.db.commit()
+            logging.info(dict(message=_(u'person added'), uid=uid, **logmsg))
+        # If browser language does not match global default language, add
+        # a profile setting
+        lang = request.accept_languages.best_match(self.config.LANGUAGES)
+        try:
+            default_lang = g.db.query(self.models.Settings).filter_by(
+                name='global').one().lang
+        except Exception:
+            default_lang = 'en'
+        if lang and lang != default_lang:
+            try:
+                g.db.add(self.models.Profile(id=gen_id(), uid=uid, item='lang',
+                                             value=lang, status='active'))
+                g.db.commit()
+            except IntegrityError:
+                # Dup entry from previous attempt
+                g.db.rollback()
+        if picture:
+            try:
+                g.db.add(self.models.Profile(
+                    id=gen_id(), uid=uid, item='picture', value=picture,
+                    status='active'))
+                g.db.commit()
+            except (DataError, IntegrityError):
+                # Dup entry from previous attempt or value too long
+                g.db.rollback()
+        return Confirmation().request(cid, template=template)
+
     def account_add(self, username, uid):
         """Add an account with the given username
 
